@@ -5,9 +5,9 @@
 # Created by the Natural History Museum in London, UK
 from ckan.plugins import toolkit
 
-from . import datastore, search, downloads
+from . import datastore, search, downloads, status
 
-blueprints = [datastore.blueprint, search.blueprint]
+blueprints = [datastore.blueprint, search.blueprint, status.blueprint]
 
 if toolkit.config.get(u'debug', False):
     blueprints.append(downloads.blueprint)
